Get_noise_sd: Get the square root of the covariance matrix associated to a...

View source: R/functional-spectral-density.R

Get_noise_sdR Documentation

Get the square root of the covariance matrix associated to a noise type

Description

Get the square root of the covariance matrix associated to a noise type

Usage

Get_noise_sd(noise.type, d.n)

Arguments

noise.type

the type of noise that is driving the MA process. See Details section.

d.n

dimension of the noise that is filtered


ftsspec documentation built on Aug. 4, 2026, 9:07 a.m.