Marginal_basis_pval: Compute the marginal p-values at each basis coefficients of...

View source: R/functional-spectral-density.R

Marginal_basis_pvalR Documentation

Compute the marginal p-values at each basis coefficients of for testing the equality of two spectral density kernels

Description

Compute the marginal p-values at each basis coefficients of for testing the equality of two spectral density kernels

Usage

Marginal_basis_pval(spec1, spec2, m, kappa.square, is.pi.multiple)

Arguments

spec1, spec2

The two sample spectral densities (at the same frequency \omega) to be compared.

m

The number of Fourier frequencies over which the periodogram operator was smoothed.

kappa.square

the L2-norm of the weight function used to estimate the spectral density operator

is.pi.multiple

A logical variable, to specify if \omega = {0, \pi} or not.


ftsspec documentation built on Aug. 4, 2026, 9:07 a.m.