View source: R/functional-spectral-density.R
| Marginal_basis_pval | R Documentation |
Compute the marginal p-values at each basis coefficients of for testing the equality of two spectral density kernels
Marginal_basis_pval(spec1, spec2, m, kappa.square, is.pi.multiple)
spec1, spec2 |
The two sample spectral densities (at the same frequency |
m |
The number of Fourier frequencies over which the periodogram operator was smoothed. |
kappa.square |
the L2-norm of the weight function used to estimate the spectral density operator |
is.pi.multiple |
A logical variable, to specify if |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.